@@ -19,9 +19,29 @@ class I18nBackendSimpleTest < I18n::TestCase
   end
 
   test "simple backend translate: given integer as a key" do
-    store_translations :en, available: { 1 => "Yes", 2 => "No" }
+    store_translations :en, available: { -1 => "Possibly", 0 => "Maybe", 1 => "Yes", 2 => "No", 3 => "Never"  }
+    assert_equal "Possibly", I18n.t(:available)[-1]
+    assert_equal "Possibly", I18n.t('available.-1')
+    assert_equal "Maybe", I18n.t(:available)[0]
+    assert_equal "Maybe", I18n.t('available.0')
     assert_equal "Yes", I18n.t(:available)[1]
     assert_equal "Yes", I18n.t('available.1')
+    assert_equal "No", I18n.t(:available)[2]
+    assert_equal "No", I18n.t('available.2')
+    assert_equal "Never", I18n.t(:available)[3]
+    assert_equal "Never", I18n.t('available.+3')
+  end
+
+  test 'simple backend translate: given integer with a leading positive/negative sign' do
+    store_translations :en, available: { -1 => "No", 0 => "Maybe", 1 => "Yes" }
+    assert_equal 'No', I18n.t(:available)[-1]
+    assert_equal 'No', I18n.t('available.-1')
+    assert_equal 'Maybe', I18n.t(:available)[+0]
+    assert_equal 'Maybe', I18n.t(:available)[-0]
+    assert_equal 'Maybe', I18n.t('available.-0')
+    assert_equal 'Maybe', I18n.t('available.+0')
+    assert_equal 'Yes', I18n.t(:available)[+1]
+    assert_equal 'Yes', I18n.t('available.+1')
   end
 
   test 'simple backend translate: given integer with a lead zero as a key' do
@@ -45,7 +65,7 @@ class I18nBackendSimpleTest < I18n::TestCase
 
   # loading translations
   test "simple load_translations: given an unknown file type it raises I18n::UnknownFileType" do
-    assert_raise(I18n::UnknownFileType) { I18n.backend.load_translations("#{locales_dir}/en.xml") }
+    assert_raises(I18n::UnknownFileType) { I18n.backend.load_translations("#{locales_dir}/en.xml") }
   end
 
   test "simple load_translations: given a YAML file name with yaml extension does not raise anything" do
@@ -66,18 +86,29 @@ class I18nBackendSimpleTest < I18n::TestCase
   end
 
   test "simple load_rb: loads data from a Ruby file" do
-    data = I18n.backend.send(:load_rb, "#{locales_dir}/en.rb")
+    data, _ = I18n.backend.send(:load_rb, "#{locales_dir}/en.rb")
     assert_equal({ :en => { :fuh => { :bah => 'bas' } } }, data)
   end
 
   test "simple load_yml: loads data from a YAML file" do
-    data = I18n.backend.send(:load_yml, "#{locales_dir}/en.yml")
-    assert_equal({ 'en' => { 'foo' => { 'bar' => 'baz' } } }, data)
+    data, _ = I18n.backend.send(:load_yml, "#{locales_dir}/en.yml")
+    if ::YAML.respond_to?(:unsafe_load_file)
+      assert_equal({ :en => { :foo => { :bar => 'baz' } } }, data)
+      assert_predicate data.dig(:en, :foo, :bar), :frozen?
+    else
+      assert_equal({ 'en' => { 'foo' => { 'bar' => 'baz' } } }, data)
+    end
   end
 
   test "simple load_json: loads data from a JSON file" do
-    data = I18n.backend.send(:load_json, "#{locales_dir}/en.json")
-    assert_equal({ 'en' => { 'foo' => { 'bar' => 'baz' } } }, data)
+    data, _ = I18n.backend.send(:load_json, "#{locales_dir}/en.json")
+
+    if JSON.respond_to?(:load_file)
+      assert_equal({ :en => { :foo => { :bar => 'baz' } } }, data)
+      assert_predicate data.dig(:en, :foo, :bar), :frozen?
+    else
+      assert_equal({ 'en' => { 'foo' => { 'bar' => 'baz' } } }, data)
+    end
   end
 
   test "simple load_translations: loads data from known file formats" do
@@ -140,6 +171,20 @@ class I18nBackendSimpleTest < I18n::TestCase
     assert_equal 'foo', I18n.t(:'1')
   end
 
+  test "simple store_translations: store translations doesn't deep symbolize keys if skip_symbolize_keys is true" do
+    data = { :foo => {'bar' => 'barfr', 'baz' => 'bazfr'} }
+
+    # symbolized by default
+    store_translations(:fr, data)
+    assert_equal Hash[:foo, {:bar => 'barfr', :baz => 'bazfr'}], translations[:fr]
+
+    I18n.backend.reload!
+
+    # not deep symbolized when configured
+    store_translations(:fr, data, skip_symbolize_keys: true)
+    assert_equal Hash[:foo, {'bar' => 'barfr', 'baz' => 'bazfr'}], translations[:fr]
+  end
+
   # reloading translations
 
   test "simple reload_translations: unloads translations" do
