@@ -1,22 +1,14 @@
 require 'minitest/autorun'
-TEST_CASE = defined?(Minitest::Test) ? Minitest::Test : MiniTest::Unit::TestCase
-
-# TODO: Remove these aliases and update tests accordingly.
-class TEST_CASE
-  alias :assert_raise :assert_raises
-  alias :assert_not_equal :refute_equal
-
-  def assert_nothing_raised(*args)
-    yield
-  end
-end
-
 require 'bundler/setup'
 require 'i18n'
 require 'mocha/setup'
 require 'test_declarative'
 
-class I18n::TestCase < TEST_CASE
+class I18n::TestCase < Minitest::Test
+  def assert_nothing_raised(*args)
+    yield
+  end
+
   def self.key_value?
     defined?(ActiveSupport)
   end
@@ -45,8 +37,8 @@ class I18n::TestCase < TEST_CASE
     I18n.backend.instance_variable_get(:@translations)
   end
 
-  def store_translations(locale, data)
-    I18n.backend.store_translations(locale, data)
+  def store_translations(locale, data, options = I18n::EMPTY_HASH)
+    I18n.backend.store_translations(locale, data, options)
   end
 
   def locales_dir
